.. :changelog:

History
-------


0.2.2 (2018-11-07)
++++++++++++++++++

* Fixed document build on Read the Docs


0.2.1 (2018-11-02)
++++++++++++++++++

* Fixed dependencies in PyPI


0.2.0 (2018-10-19)
++++++++++++++++++

* Added Anonymize module to encrypt customer identifiable data in a dataset
* Removed PyPy support due to PyPy and numpy incompatibility


0.1.3 (2018-10-16)
++++++++++++++++++

* Minor bug fix


0.1.2 (2018-10-16)
++++++++++++++++++

* Colors module refactored and additional tests written
* Documentation updated
* Added support for Python 3.5+


0.1.1 (2018-10-15)
++++++++++++++++++

* Documentation added


0.1.0 (2018-10-15)
++++++++++++++++++

* First release on PyPI.
* Colors module providing inforcehub brand colors
